// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (European Space Agency) 
// July 30, 1999
//
#ifndef CalIndexSet_H
#define CalIndexSet_H

#include <string>
#include <Dal.h>
#include <STime.h>

#include "CalIndex.h"

#include "CcfConstituent.h"

class CalIndexSet {

 public:

  CalIndexSet(const string& name, const bool& master,
	      const bool& fullpath, const string& category,
	      const STime& analysisdate = STime("now"),
	      const STime& observationdate = STime("now"));
  CalIndexSet(const string& name, const bool& readonly=false);
  ~CalIndexSet() {};

  CalIndex calibrationIndex(const string& name) const;

  void insert(CcfConstituent * c);
  void close();
  unsigned long size() const;
  CcfConstituent * getConstituent(const unsigned int& row) const;
  
 private:

  bool _can_insert, _fullpath, _master;
  DataSet * _set;
  string _category;

};

#endif
