// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (European Space Agency) 
// January 31, 2000
//
#include "cifdiff.h"
#include <Tracer.h>
#include <string>
#include <algorithm>
#include "CalIndexSet.h"
#include <param.h>
#include <fstream>
#include <errstr.h>

static void diff_them(CalIndex cif1, CalIndex cif2, ostream &out){
  PROC
  cif1.sort(CcfConstituent::compare);
  cif2.sort(CcfConstituent::compare);
  CalIndex cif3("cif3");
  set_difference(cif1.begin(), cif1.end(), cif2.begin(), cif2.end(), back_inserter(cif3), CcfConstituent::compare);
  if(cif3.size() == 0)
    out << "** none **" << endl;
  else
    for(CalIndex::const_iterator i = cif3.begin(); i != cif3.end(); i++)
      out << (*i)->name() << endl;
  ENDPROC
}

static void tell_them(const string& c1, const string& c2,
		      const CalIndex& cif1, const CalIndex& cif2,
		      ostream& os){
  PROC
  os << "CCF constituents that are in " << c1 << " but not in "
      << c2 << ":" << endl;
  diff_them(cif1, cif2, os);
  os << "CCF constituents that are in " << c2 << " but not in "
      << c1 << ":" << endl;
  diff_them(cif2, cif1, os);  
  ENDPROC
}

void cifdiff() {
  PROC
  string c1 = stringParameter("calindex1set");
  string c2 = stringParameter("calindex2set");
  CalIndex cif1 = CalIndexSet(c1).calibrationIndex("cif1");
  CalIndex cif2 = CalIndexSet(c2).calibrationIndex("cif2");
  if(booleanParameter("withfile")){
    ofstream o(stringParameter("outfile").c_str());
    tell_them(c1,c2,cif1,cif2,o);
  } else {
    errstr << endl;
    tell_them(c1,c2,cif1,cif2,errstr);
    errstr << Sas::message(Msg::App, Msg::Always);
  }
  ENDPROC
}
