// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (European Space Agency) 
// April 04, 2000
//
#include "cifremove.h"
#include <Tracer.h>
#include <string>
#include "CalIndexSet.h"
#include <param.h>
#include <errstr.h>

void cifremove() {
  PROC
  if(parameterCount("scopes") != parameterCount("types"))
    errstr << "The number of scopes (" << parameterCount("scopes") << ") does not match the number of types (" << parameterCount("types") << ")." <<Sas::error("ParameterCountMismatch");
  string s = stringParameter("calindexset");
  CalIndexSet cset = CalIndexSet(s);
  CalIndex cif = cset.calibrationIndex(s);
  cset.close(); // must close it, or it cannot be overwritten
  for(int i = 0; i < parameterCount("scopes"); i++){
    if(!cif.removeConstituent(stringParameter("types",i),stringParameter("scopes",i)))
      errstr << s << " contains no constituent matching " << stringParameter("types",i) << "/" << stringParameter("scopes",i) << Sas::warning("NoMatchingCcfConstituent");
  }
  cif.save();
  ENDPROC
}
